package com.ruoyi.project.asset.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.project.asset.service.ITLeakagePointsService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.project.asset.domain.TLeakagePoints;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 漏点清单Controller
 * 
 * @author ruoyi
 * @date 2024-03-28
 */
@RestController
@RequestMapping("/asset/points")
public class TLeakagePointsController extends BaseController
{
    @Autowired
    private ITLeakagePointsService tLeakagePointsService;

    /**
     * 查询漏点清单列表
     */
    @PreAuthorize("@ss.hasPermi('asset:points:list')")
    @GetMapping("/list")
    public TableDataInfo list(TLeakagePoints tLeakagePoints)
    {
        startPage();
        List<TLeakagePoints> list = tLeakagePointsService.selectTLeakagePointsList(tLeakagePoints);
        return getDataTable(list);
    }

    /**
     * 导出漏点清单列表
     */
    @PreAuthorize("@ss.hasPermi('asset:points:export')")
    @Log(title = "漏点清单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TLeakagePoints tLeakagePoints)
    {
        List<TLeakagePoints> list = tLeakagePointsService.selectTLeakagePointsList(tLeakagePoints);
        ExcelUtil<TLeakagePoints> util = new ExcelUtil<TLeakagePoints>(TLeakagePoints.class);
        util.exportExcel(response, list, "漏点清单数据");
    }

    /**
     * 获取漏点清单详细信息
     */
    @PreAuthorize("@ss.hasPermi('asset:points:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tLeakagePointsService.selectTLeakagePointsById(id));
    }

    /**
     * 新增漏点清单
     */
    @PreAuthorize("@ss.hasPermi('asset:points:add')")
    @Log(title = "漏点清单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TLeakagePoints tLeakagePoints)
    {
        return toAjax(tLeakagePointsService.insertTLeakagePoints(tLeakagePoints));
    }

    /**
     * 修改漏点清单
     */
    @PreAuthorize("@ss.hasPermi('asset:points:edit')")
    @Log(title = "漏点清单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TLeakagePoints tLeakagePoints)
    {
        return toAjax(tLeakagePointsService.updateTLeakagePoints(tLeakagePoints));
    }

    /**
     * 删除漏点清单
     */
    @PreAuthorize("@ss.hasPermi('asset:points:remove')")
    @Log(title = "漏点清单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tLeakagePointsService.deleteTLeakagePointsByIds(ids));
    }
}
